import os.path
__dir__ = os.path.split(os.path.abspath(os.path.realpath(__file__)))[0]
data_location = os.path.join(__dir__, "verilog")
src = "https://github.com/olofk/serv"

# Module version
version_str = "1.1.0.post146"
version_tuple = (1, 1, 0, 146)
try:
    from packaging.version import Version as V
    pversion = V("1.1.0.post146")
except ImportError:
    pass

# Data version info
data_version_str = "1.1.0.post28"
data_version_tuple = (1, 1, 0, 28)
try:
    from packaging.version import Version as V
    pdata_version = V("1.1.0.post28")
except ImportError:
    pass
data_git_hash = "e59fe5346aabc555b8ed21b4e09eb14015340e6b"
data_git_describe = "1.1.0-28-ge59fe53"
data_git_msg = """\
commit e59fe5346aabc555b8ed21b4e09eb14015340e6b
Author: Olof Kindgren <olof.kindgren@gmail.com>
Date:   Mon Jan 3 18:12:48 2022 +0100

    Refactor docs and add interface documentation

"""

# Tool version info
tool_version_str = "0.0.post118"
tool_version_tuple = (0, 0, 118)
try:
    from packaging.version import Version as V
    ptool_version = V("0.0.post118")
except ImportError:
    pass


def data_file(f):
    """Get absolute path for file inside pythondata_cpu_serv."""
    fn = os.path.join(data_location, f)
    fn = os.path.abspath(fn)
    if not os.path.exists(fn):
        raise IOError("File {f} doesn't exist in pythondata_cpu_serv".format(f))
    return fn



#!/usr/bin/env python3
#
# This is free and unencumbered software released into the public domain.
#
# Anyone is free to copy, modify, publish, use, compile, sell, or
# distribute this software, either in source code form or as a compiled
# binary, for any purpose, commercial or non-commercial, and by any
# means.

from sys import argv

binfile = argv[1]
nwords = int(argv[2])

with open(binfile, "rb") as f:
    bindata = f.read()

assert len(bindata) < 4*nwords
assert len(bindata) % 4 == 0

for i in range(nwords):
    if i < len(bindata) // 4:
        w = bindata[4*i : 4*i+4]
        print("%02x%02x%02x%02x" % (w[3], w[2], w[1], w[0]))
    else:
        print("0")

